@@ -419,7 +419,8 @@ G - G-language Genome Analysis Environment core interface module
          This method provides powerful means to search within the G-language genome
          data object with keywords. Given a set of keywords, this method returns
          the list of feature IDs corresponding to the search query. In G-language Shell,
-         search results are also directly printed out.
+         search results are also directly printed out (you can specify -print=>1 option
+         in API mode to print within your program).
 
          eg. @features = $gb->find('RNA', 'tyrosine');    # multiple keywords are allowed.
 
