@@ -118,11 +118,17 @@ sub find {
     my @args = @_;
     my (@keywords, %keyhash, @results);
     my $i = 0;
+    my $print = 0;
 
     while(defined $args[$i]){
         if (substr($args[$i], 0, 1) eq '-' && substr($args[$i], 1, 1) !~ /[0-9]/){
-            $keyhash{substr($args[$i],1)} = $args[$i + 1];
-            $i += 2;
+	    if (substr($args[$i],1) eq 'print'){
+		$print = 1;
+		$i +=2;
+	    }else{
+		$keyhash{substr($args[$i],1)} = $args[$i + 1];
+		$i += 2;
+	    }
         }else{
 	    push(@keywords, $args[$i]);
             $i ++;
@@ -153,15 +159,17 @@ sub find {
 	push(@results, $feat) unless($flag);
     }
 
-    if(msg_ask_interface() eq 'Shell'){
+    if(msg_ask_interface() eq 'Shell' || $print){
 	foreach my $feat (@results){
 	    my $gene = $this->{$feat}->{gene} || $this->{$feat}->{locus_tag} || $feat;
 	    my $ec = $this->{$feat}->{EC_number};
 	    $ec =~ s/\s+/,/g;
 	    $ec = '(' . $ec . ')' if (length $ec);
 
-	    printf "     %s\t%s\t%s\t%s..%s\t%s\t%s %s\n", $feat, $gene, $this->{$feat}->{type}, 
-	    $this->{$feat}->{start}, $this->{$feat}->{end}, $this->{$feat}->{direction}, $this->{$feat}->{product}, $ec;
+	    msg_send(
+		     sprintf("     %s\t%s\t%s\t%s..%s\t%s\t%s %s\n", $feat, $gene, $this->{$feat}->{type}, 
+			     $this->{$feat}->{start}, $this->{$feat}->{end}, $this->{$feat}->{direction}, $this->{$feat}->{product}, $ec)
+		     );
 	}
     }
 
