@@ -46,6 +46,8 @@ our @EXPORT = qw(
 	     say
 	     p
 	     puts
+	     readFile
+	     writeFile
 );
 
 #::::::::::::::::::::::::::::::
@@ -76,6 +78,91 @@ sub say{
     print join(',', @_), "\n";
 }
 
+
+
+
+=head2 readFile
+
+  Name: readFile   -   reads in text from a file
+
+  Description:
+   This method simply reads all contents of a file and returns
+   the contents as a scalar or an array of lines depending on the
+   context. Specify second argument as 1 to chomp each lines.
+
+  Usage: 
+    #in array context
+    @text = readFile($filename);
+
+    #in scalar context
+    $text = readFile($filename);
+
+    
+ Options:
+    none
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+    20090313-01 initial posting
+
+=cut
+
+sub readFile{
+    my $file = shift;
+    my $chomp = shift || 0;
+    my @result;
+
+    open(FILE, $file) || die($!);
+    while(<FILE>){
+	chomp if($chomp);
+	push(@result, $_);
+    }
+    close(FILE);
+
+    if(wantarray()){
+	return @result;
+    }else{
+	return join('', @result);
+    }
+}
+
+
+=head2 readFile
+
+  Name: writeFile   -   writes a given scalar to a file
+
+  Description:
+   This method simply writes a given scalar value (text) to a file.
+   Filename should be given as the second argument, and if ommited,
+   a file named 'out.txt' is created.
+
+  Usage: 
+    $filename = writeFile($text, $filename);
+
+ Options:
+    none
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+    20090313-01 initial posting
+
+=cut
+
+sub writeFile{
+    my $data = shift;
+    my $file = shift || "out.txt";
+
+    open(OUT, '>' . $file) || die($!);
+    print OUT $data;
+    close(OUT);
+
+    return $file;
+}
+
 sub msg_gimv{
     my $file = shift;
     my $time = 'gimv' . time();
@@ -159,7 +246,7 @@ sub msg_send{
 	$data{"term"} .= $tmp;
 	&$term($tmp);
     }else{
-	print STDOUT @msg;
+	print @msg;
     }
 }
 
