@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2008 Keio University
+#     Copyright (C) 2001-2009 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: GCskew.pm,v 1.3 2002/08/16 15:03:36 gaou Exp $
@@ -29,7 +29,9 @@ package G::Seq::GCskew;
 use SubOpt;
 use G::Messenger;
 use G::Tools::Graph;
+use G::Tools::Statistics;
 use G::Seq::Primitive;
+use autouse 'Algorithm::Numerical::Shuffle'=>qw(shuffle);
 
 use strict;
 use base qw(Exporter);
@@ -397,24 +399,34 @@ sub leading_strand {
     bacterial genomes, caused by replicational selection. 
 
     GCSI is calculated by the following formula:
-        GCSI = ((SR/6000) + (dist/600))/2
-    where SR is the ratio of Fourier spectral strengths of 1Hz over the average,
-    and dist is the Euclidean distance between the vertices of cumulative GC skew.
+        GCSI = sqrt((SA/6000) * (dist/600))
+    where SA is the spectral amplitude of Fourier power spectrum at 1Hz,
+    and dist is the normalized Euclidean distance between the vertices of 
+    cumulative GC skew.
 
     GCSI ranges from 0 (no observable skew) to 1 (strong skew), and Archaeal genomes
     that have multiple replication origins and therefore have no observable skew
     mostly have GCSI below 0.05. Escherichia coli genome has values around 0.10.
 
+    Version 1 of GCSI required fixed number of windows (4096), but the new GCSI
+    version 2 (also known as generalized GCSI: gGCSI) is invariant of the number
+    of windows. GCSI version 1 is calculated as an arithmetic mean (as opposed to 
+    the geometric mean of gGCSI) of SR (spectral ratio, the signal-to-noise ratio
+    of 1Hz power spectrum) and dist. 
+
   Usage: 
     $gcsi = gcsi($genome);               # scalar context
        or
-    ($gcsi, $sr, $dist) = gcsi($genome); # array context
+    ($gcsi, $sa, $dist) = gcsi($genome); # array context
 
   Options:
+   -version     version of GCSI. generalized GCSI is selected by default. (default: 2)
    -window      number of windows. must be a power of 2. (default: 4096)
    -purine      use purine skew for calculation (default: 0)
    -keto        use keto skew for calculation (default: 0)
    -at          use AT skew for calculation (default: 0)
+   -p           calculate p-value when GCSI version 2 is selected (default: 0)
+                returned values are ($gcsi, $sa, $dist, $p)
 
   References:
     1. Arakawa K, Tomita M (2007) "The GC skew index: a measure of genomic compositional 
@@ -424,6 +436,7 @@ sub leading_strand {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+   20090311-01 updated to version 2, with -p and -version options
    20080421-01 added -at, -purine and -keto options
    20070313-01 added error message for when genome size is too small
    20070707-01 initial posting
@@ -432,59 +445,65 @@ sub leading_strand {
 
 
 sub gcsi{
-    require Statistics::Descriptive;
     require Math::FFT;
 
-    opt_default(window=>4096, purine=>0, keto=>0, at=>0);
+    opt_default(window=>4096, purine=>0, keto=>0, at=>0, version=>2, p=>0);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
-    my $power = opt_val("window");
-    my $purine = opt_val("purine");
-    my $keto = opt_val("keto");
-    my $at = opt_val("at");
-    my $lowpass = opt_val("filter");
+    my %opt = opt_val();
 
-    my $window = int(length($gb->{SEQ}) / $power);
+    my $window = int(length($gb->{SEQ}) / $opt{'window'});
     if($window < 10){
 	die("Error in gcsi: number of windows is too large, or the genome is too small.\n" . 
-	    "GCSI would not be accurate for genomes smaller than 100,000 bp\n");
+	    "GCSI would not be accurate for window size less than 100 bp.\n");
     }
-    my @gcskew = gcskew($gb, -output=>"/dev/null", -window=>$window);
-    my @cumgcskew = gcskew($gb, -output=>"/dev/null", -window=>$window, -cumulative=>1, -purine=>$purine, -keto=>$keto, -at=>$at);
+    my @gcskew = gcskew($gb, -output=>'/dev/null', -window=>$window, -purine=>$opt{'purine'}, -keto=>$opt{'keto'}, -at=>$opt{'at'});
 
-    while(scalar @gcskew > $power){
-        pop @gcskew;
+    while(scalar @gcskew > $opt{'window'}){
+	pop @gcskew;
     }
 
-    my $fft = new Math::FFT([@gcskew]);
-    my $coeff = $fft->rdft();
-    my $coeff2 = [@{$coeff}];
-    my $spctrm = $fft->spctrm();
-    my @spectrum = @$spctrm;
+    local *gcsicore = sub{
+	my @gcskew = @_;
+	my @cumgcskew = cumulative(@gcskew);
 
-    shift @spectrum;
-    my $first = shift @spectrum;
+	my $fft = new Math::FFT([@gcskew]);
+	my @spectrum = @{$fft->spctrm()};
+	shift @spectrum;
+	my $first = shift @spectrum;
 
-    my $stat = Statistics::Descriptive::Full->new();
-    $stat->add_data(splice(@spectrum, 0, 50));
-    my $maxi = $stat->maxdex() + 2;
-    my $max = $stat->max();
-    my $avg50 = $stat->mean();
+	my $dist = abs(max(@cumgcskew)) + abs(min(@cumgcskew));
+	my ($gcsi, $sr);
 
-    undef $stat;
-    my $stat = Statistics::Descriptive::Full->new();
-    $stat->add_data(@spectrum);
-    my $avg = $stat->mean();
+	if($opt{'version'} == 1){
+	    $sr = $first/mean(@spectrum);
+	    $gcsi = ($sr/6000 + $dist/600)/2;
+	}else{
+	    $dist *= 4096/$opt{'window'};
+	    $sr = 40 * (($first * 6000 * 100) ** 0.4);
+	    $gcsi = sqrt($sr/6000 * $dist/600);
+	}
 
-    undef $stat;
-    my $stat = Statistics::Descriptive::Full->new();
-    $stat->add_data(@cumgcskew);
-    my $cmax = $stat->max();
-    my $cmin = $stat->min();
+	return ($gcsi, $sr, $dist);
+    };
 
-    my $sr = $first/$avg;
-    my $dist = abs($cmax)+abs($cmin);
-    my $gcsi = ($sr/6000 + $dist/600)/2;
+    my ($gcsi, $sr, $dist) = gcsicore(@gcskew);
+
+    if($opt{'p'}){
+	require Statistics::Distributions;
+
+	my @random;
+	for (1..100){
+	    my ($rgcsi, undef, undef) = gcsicore(shuffle(@gcskew));
+	    push(@random, $rgcsi);
+	}
+
+	my $z = abs(($gcsi - mean(@random))/standard_deviation(@random));
+	my $p = Statistics::Distributions::uprob($z) * 2;
+#	my $rcmd = new Rcmd();
+#	say $rcmd->normtest(@random);
+	return ($gcsi, $sr, $dist, $z, $p);
+    }
 
     if(wantarray()){
 	return ($gcsi, $sr, $dist);
